@@ -49,11 +49,15 @@ class combined(Variable):
     value_type = float
     entity = TaxUnit
     definition_period = YEAR
-    documentation = "Sum of iitax and payrolltax"
+    label = "Taxes"
+    documentation = "Total federal income and payroll tax liability."
     unit = USD
 
     def formula(tax_unit, period, parameters):
-        return add(tax_unit, period, ["iitax", "payrolltax"])
+        return add(tax_unit, period, ["iitax", "employee_payrolltax"])
+
+
+tax = variable_alias("tax", combined)
 
 
 class filer_earned(Variable):
@@ -88,6 +92,9 @@ class earned(Variable):
         return max_(0, add(person, period, ["e00200", "setax"]) - adjustment)
 
 
+earned_income = variable_alias("earned_income", earned)
+
+
 class was_plus_sey(Variable):
     value_type = float
     entity = Person
@@ -124,6 +131,11 @@ class rptc(Variable):
     unit = USD
 
 
+refundable_payroll_tax_credit = variable_alias(
+    "refundable_payroll_tax_credit", rptc
+)
+
+
 class rptc_p(Variable):
     value_type = float
     entity = TaxUnit
@@ -193,12 +205,16 @@ class iitax(Variable):
     entity = TaxUnit
     definition_period = YEAR
     unit = USD
-    documentation = "Total federal individual income tax liability; appears as INCTAX variable in tc CLI minimal output"
+    label = "Federal income tax"
+    documentation = "Total federal individual income tax liability."
 
     def formula(tax_unit, period, parameters):
         return tax_unit("c09200", period) - tax_unit("refund", period)
 
 
+federal_income_tax = variable_alias("federal_income_tax", iitax)
+
+
 class num(Variable):
     value_type = int
     entity = TaxUnit
@@ -221,7 +237,7 @@ class payrolltax(Variable):
     label = "Payroll tax"
     definition_period = YEAR
     unit = USD
-    documentation = "Total (employee + employer) payroll tax liability; appears as PAYTAX variable in tc CLI minimal output (payrolltax = ptax_was + setax + ptax_amc)"
+    documentation = "Total (employee + employer) payroll tax liability."
 
     def formula(tax_unit, period):
         COMPONENTS = [
@@ -236,7 +252,8 @@ class payrolltax(Variable):
 class employee_payrolltax(Variable):
     value_type = float
     entity = TaxUnit
-    label = "Employee's share of payroll tax"
+    label = "Employee's payroll tax"
+    documentation = "Share of payroll tax liability paid by the employee."
     definition_period = YEAR
     unit = USD
 
@@ -252,21 +269,8 @@ class refund(Variable):
     unit = USD
 
     def formula(tax_unit, period, parameters):
-        ctc_refundable = parameters(
-            period
-        ).irs.credits.child_tax_credit.refundable
-        ctc_refund = tax_unit("c07220", period) * ctc_refundable
-        REFUND_COMPONENTS = [
-            "eitc",
-            "c11070",
-            "c10960",
-            "cdcc_refund",
-            "recovery_rebate_credit",
-            "personal_refundable_credit",
-            "ctc_new",
-            "rptc",
-        ]
-        return add(tax_unit, period, REFUND_COMPONENTS) + ctc_refund
+        credits = parameters(period).irs.credits.refundable
+        return add(tax_unit, period, credits)
 
 
 class sep(Variable):
@@ -457,7 +461,7 @@ class taxbc(Variable):
             # Calculate rate applied to pass-through income on in the same
             # way, but as treated as if stacked on top of regular income
             # (which is not taxed again)
-            pt_threshold = max(
+            pt_threshold = max_(
                 individual_income.pass_through.bracket.thresholds[str(i)][mars]
                 - pt_tbase,
                 0,
@@ -840,6 +844,9 @@ class c05800(Variable):
         return add(tax_unit, period, ["taxbc", "c09600"])
 
 
+income_tax_before_credits = variable_alias("income_tax_before_credits", c05800)
+
+
 class c07100(Variable):
     value_type = float
     entity = TaxUnit
@@ -849,6 +856,10 @@ class c07100(Variable):
     )
     unit = USD
 
+    def formula(tax_unit, period, parameters):
+        credits = parameters(period).irs.credits.non_refundable
+        return add(tax_unit, period, credits)
+
 
 class c07180(Variable):
     value_type = float
@@ -866,13 +877,17 @@ class c07180(Variable):
             return min_(
                 max_(
                     0,
-                    tax_unit("c05800", period)
-                    - tax_unit("filer_e07300", period),
+                    tax_unit("c05800", period) - tax_unit("e07300", period),
                 ),
                 tax_unit("c33200", period),
             )
 
 
+child_dependent_care_expense_credit = variable_alias(
+    "child_dependent_care_expense_credit", c07180
+)
+
+
 class cdcc_refund(Variable):
     value_type = float
     entity = TaxUnit
@@ -971,7 +986,9 @@ class section_22_income(Variable):
         is_dependent = person("is_tax_unit_dependent", period)
         num_elderly = tax_unit.sum(is_elderly & ~is_dependent)
         disability_income = person("total_disability_payments", period)
-        non_elderly_disability_income = disability_income * ~is_elderly
+        non_elderly_disability_income = tax_unit.sum(
+            disability_income * ~is_elderly
+        )
 
         cap = (
             num_elderly * elderly_disabled.amount.one_qualified
@@ -1009,11 +1026,7 @@ class c07200(Variable):
         return elderly_disabled.rate * tax_unit("section_22_income", period)
 
 
-class c07220(Variable):
-    value_type = float
-    entity = TaxUnit
-    definition_period = YEAR
-    documentation = "Child tax credit (adjusted) from Form 8812"
+elderly_disabled_credit = variable_alias("elderly_disabled_credit", c07200)
 
 
 class c07230(Variable):
@@ -1031,6 +1044,9 @@ class c07230(Variable):
         return add(tax_unit, period, ELEMENTS)
 
 
+education_tax_credits = variable_alias("education_tax_credits", c07230)
+
+
 class c07240(Variable):
     value_type = float
     entity = TaxUnit
@@ -1098,6 +1114,11 @@ class c09200(Variable):
     unit = USD
     documentation = "Income tax liability (including othertaxes) after non-refundable credits are used, but before refundable credits are applied"
 
+    def formula(tax_unit, period, parameters):
+        tax_net_nonrefundable_credits = max_(
+            0, tax_unit("c05800", period) - tax_unit("c07100", period)
+        )
+
 
 class c09600(Variable):
     value_type = float
@@ -1198,7 +1219,7 @@ class c09600(Variable):
         line62 = line42 + cgtax1 + cgtax2 + cgtax3 + line61
         line64 = min_(line3163, line62)
         line31 = where(form_6251_part_iii_required, line64, line3163)
-        e07300 = tax_unit("filer_e07300", period)
+        e07300 = tax_unit("e07300", period)
 
         # Form 6251, Part II bottom
         line32 = where(
@@ -1240,6 +1261,9 @@ class c11070(Variable):
     unit = USD
 
 
+ctc_refund = variable_alias("ctc_refund", c11070)
+
+
 class c17000(Variable):
     value_type = float
     entity = TaxUnit
@@ -1441,11 +1465,12 @@ class c59660(Variable):
         amount = min_(amount_with_phasein, max_with_phaseout)
         age_head = tax_unit("age_head", period)
         age_spouse = tax_unit("age_spouse", period)
-        head_age_is_eligible = (
-            eitc.eligibility.age.min <= age_head <= eitc.eligibility.age.max
+        head_age_is_eligible = (eitc.eligibility.age.min <= age_head) & (
+            age_head <= eitc.eligibility.age.max
         )
         spouse_age_is_eligible = is_joint * (
-            eitc.eligibility.age.min <= age_spouse <= eitc.eligibility.age.max
+            (eitc.eligibility.age.min <= age_spouse)
+            & (age_spouse <= eitc.eligibility.age.max)
         )
         inferred_eligibility = (
             (age_head == 0)
@@ -1553,22 +1578,6 @@ class ctc_new(Variable):
     unit = USD
 
 
-class odc(Variable):
-    value_type = float
-    entity = TaxUnit
-    definition_period = YEAR
-    documentation = "Other Dependent Credit"
-    unit = USD
-
-
-class personal_refundable_credit(Variable):
-    value_type = float
-    entity = TaxUnit
-    definition_period = YEAR
-    documentation = "Personal refundable credit"
-    unit = USD
-
-
 class recovery_rebate_credit(Variable):
     value_type = float
     entity = TaxUnit
@@ -1579,14 +1588,6 @@ class recovery_rebate_credit(Variable):
     unit = USD
 
 
-class personal_nonrefundable_credit(Variable):
-    value_type = float
-    entity = TaxUnit
-    definition_period = YEAR
-    documentation = "Personal nonrefundable credit"
-    unit = USD
-
-
 class charity_credit(Variable):
     value_type = float
     entity = TaxUnit
@@ -1779,16 +1780,6 @@ class pre_c04600(Variable):
         )
 
 
-class codtc_limited(Variable):
-    value_type = float
-    entity = TaxUnit
-    definition_period = YEAR
-    documentation = (
-        "search taxcalc/calcfunctions.py for how calculated and used"
-    )
-    unit = USD
-
-
 class ptax_amc(Variable):
     value_type = float
     entity = TaxUnit
